@@ -1,55 +1,60 @@
 /*---------------------------------------------------------------------------
- *	$Id: cm4_functions.h 9545 2011-07-27 19:31:54Z pwessel $
+ *  $Id: cm4_functions.h 12822 2014-01-31 23:39:56Z remko $
  *
  *
- *  File:	cm4_functions.h
+ *  File:       cm4_functions.h
  *
  *  Functions required to compute CM4 magnetic components
  *
  *  Authors:    J. Luis translated from original Fortran code
- *		P. Wessel further massaged it into this form
- *		
- *  Version:	1.0
- *  Revised:	1-MAY-2009
- * 
+ *              P. Wessel further massaged it into this form
+ *
+ *  Version:    1.0
+ *  Revised:    1-MAY-2009
+ *
  *-------------------------------------------------------------------------*/
 
+#ifndef _CM4_FUNCTIONS_H
+#define _CM4_FUNCTIONS_H
+
+#include "gmt_dev.h"
+
 struct MGD77_CM4 {
-	struct L {	/*  */
+	struct CM4_L {	/*  */
 		int curr;
 		int curr_components[4];
 		int n_curr_components;
 		int curr_sources[4];
 		int n_curr_sources;
-	} L;
-	struct D {	/*  */
+	} CM4_L;
+	struct CM4_D {	/*  */
 		int active;
 		int index; 
 		int load;
 		double *dst;
 		char *path;
-	} D;
-	struct I {	/*  */
+	} CM4_D;
+	struct CM4_I {	/*  */
 		int active;
 		int index; 
 		int load;
 		double F107;
 		char *path;
-	} I;
-	struct F {	/* -F<xymrw> */
+	} CM4_I;
+	struct CM4_F {	/* -F<xymrw> */
 		int active;
 		int field_components[7];
 		int n_field_components;
 		int field_sources[7];
 		int n_field_sources;
-	} F;
-	struct G {	/*  */
+	} CM4_F;
+	struct CM4_G {	/*  */
 		int geodetic;
-	} G;
-	struct M {	/*  */
+	} CM4_G;
+	struct CM4_M {	/*  */
 		char *path;
-	} M;
-	struct DATA {	/* */
+	} CM4_M;
+	struct CM4_DATA {	/* */
 		int pred[6];
 		int n_pts;
 		int n_times;
@@ -57,12 +62,14 @@ struct MGD77_CM4 {
 		int coef;
 		double	gmdl[1];
 		double	*out_field;
-	} DATA;
-	struct S {	/*  */
+	} CM4_DATA;
+	struct CM4_S {	/*  */
 		int nlmf[2];
 		int nhmf[2];
-	} S;
+	} CM4_S;
 };
 
-int MGD77_cm4field (struct MGD77_CM4 *Ctrl, double *p_lon, double *p_lat, double *p_alt, double *p_date);
-void MGD77_CM4_init (struct MGD77_CONTROL *F, struct MGD77_CM4 *CM4);
+int MGD77_cm4field (struct GMT_CTRL *GMT, struct MGD77_CM4 *Ctrl, double *p_lon, double *p_lat, double *p_alt, double *p_date);
+EXTERN_MSC void MGD77_CM4_init (struct GMT_CTRL *GMT, struct MGD77_CONTROL *F, struct MGD77_CM4 *CM4);
+
+#endif /* _CM4_FUNCTIONS_H */
