@@ -1,9 +1,14 @@
 /*-------------------------------------------------------------------------
- *	$Id: mgd77_IGF_coeffs.h 10173 2014-01-01 09:52:34Z pwessel $
+ *	$Id: mgd77_IGF_coeffs.h 15178 2015-11-06 10:45:03Z fwobbe $
  * 
- *    Copyright (c) 2005-2014 by P. Wessel
+ *    Copyright (c) 2005-2015 by P. Wessel
  *    See README file for copying and redistribution conditions.
  */
+
+/*!
+ * \file mgd77_IGF_coeffs.h
+ * \brief  
+ */
  
 #define MGD77_IGF24_G0	978052.0
 #define MGD77_IGF30_G0	978049.0
