@@ -1,7 +1,7 @@
 /*---------------------------------------------------------------------------
- *	$Id: mgd77_init.h 10173 2014-01-01 09:52:34Z pwessel $
+ *	$Id: mgd77_init.h 15178 2015-11-06 10:45:03Z fwobbe $
  *
- *    Copyright (c) 2005-2014 by P. Wessel
+ *    Copyright (c) 2005-2015 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *
  *  File:	mgd77_init.h
@@ -9,7 +9,7 @@
  *  Include file for mgd77.c
  *
  *  Authors:    Paul Wessel, Primary Investigator, SOEST, U. of Hawaii
- *				Michael Chandler, Ph.D. Student, SOEST, U. of Hawaii
+ *		Michael Chandler, Affiliate Researcher, SOEST, U. of Hawaii
  *		
  *  This include file contains initializations for the MGD77 system.
  *  MUST BE INCUDED AFTER mgd77.h IN mgd77.c
@@ -19,6 +19,11 @@
  * 
  *-------------------------------------------------------------------------*/
 
-GMT_LONG MGD77_format_allowed[MGD77_N_FORMATS] = {TRUE, TRUE, TRUE, TRUE};	/* By default we allow opening of files in any format.  See MGD77_Ignore_Format() */
+/*!
+ * \file mgd77_init.h
+ * \brief Include file for mgd77.c
+ */
+
+bool MGD77_format_allowed[MGD77_N_FORMATS] = {true, true, true, true};	/* By default we allow opening of files in any format.  See MGD77_Ignore_Format() */
 
 char *MGD77_suffix[MGD77_N_FORMATS] = {"mgd77", "nc", "dat", "m77t"};
