@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77_recalc.h 9923 2012-12-18 20:45:53Z pwessel $
+ *	$Id: mgd77_recalc.h 15178 2015-11-06 10:45:03Z fwobbe $
  *
- *    Copyright (c) 2004-2013 by P. Wessel
+ *    Copyright (c) 2004-2015 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /* Here lies some defines and a structure of items that are used when we
@@ -14,6 +14,11 @@
  * been turned OFF [Default is ON].
  */
 
+/*!
+ * \file mgd77_recalc.h
+ * \brief  
+ */
+
 #define N_E77_CORR_FIELDS	5
 /* The array indices 0-3 for these 4 fields */
 #define E77_CORR_FIELD_TWT	(MGD77_COL_ADJ_TWT-1)
@@ -39,9 +44,9 @@ struct MGD77_E77_APPLY {
 	   3. Recalculate mag using the latest IGRF reference field and mtf1
 	   4. Recalculate faa using the latest IGF80 reference field and gobs
 	*/
-	GMT_LONG apply_corrections;	/* TRUE if one or more corrections are requested */
-	GMT_LONG correction_requested[N_E77_CORR_FIELDS];	/* TRUE for each field we must correct */
-	GMT_LONG got_it[MGD77_SET_COLS];	/* TRUE for each original MGD77 column that was requested among the output columns */
+	bool apply_corrections;	/* true if one or more corrections are requested */
+	bool correction_requested[N_E77_CORR_FIELDS];	/* true for each field we must correct */
+	bool got_it[MGD77_SET_COLS];	/* true for each original MGD77 column that was requested among the output columns */
 	int needed[N_E77_AUX_FIELDS];	/* 0 if aux field not used, 1 if part of output cols, 2 is allocated separately */
 	int col[N_E77_CORR_FIELDS];	/* The output column number for each corrected field */
 	int id[N_E77_CORR_FIELDS];	/* The id number for each corrected field */
