@@ -1,8 +1,8 @@
 /* -------------------------------------------------------------------
- *	$Id: mgd77_rls_coeffs.h 10173 2014-01-01 09:52:34Z pwessel $
+ *	$Id: mgd77_rls_coeffs.h 15178 2015-11-06 10:45:03Z fwobbe $
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
- *    Copyright (c) 2004-2014 by P. Wessel and M. T. Chandler
+ *    Copyright (c) 2004-2015 by P. Wessel and M. T. Chandler
  *	File:	mgd77_rls_coeffs.c
  *
  *	Tables consisting of regression statistics for (in this order):
@@ -31,6 +31,11 @@
  * 
  * ------------------------------------------------------------------*/
 
+/*!
+ * \file mgd77_rls_coeffs.h
+ * \brief  
+ */
+
 #define RLS_N_DEPTH         4490
 #define RLS_N_DEPTH_ROWS    39
 #define RLS_N_FAA           1614
